/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Simon Woodside <sbwoodside@yahoo.com> (Original Author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#import "GecoaRDFUtils.h"

#import "NSString+Utils.h"

#include "nsCRT.h"
#include "nsIRDFDataSource.h"
#include "nsIRDFService.h"
#include "nsIRDFLiteral.h"
#include "nsIRDFResource.h"
#include "nsIRDFContainer.h"
#include "nsIRDFContainerUtils.h"
#include "nsRDFCID.h"

#include "nsComponentManagerUtils.h"
#include "nsIServiceManagerUtils.h"

#include "nsString.h"


@interface GecoaRDFUtils (Private)
@end

#pragma mark -

@implementation GecoaRDFUtils

+ (NSString*)getTextForNode:(nsIRDFNode *)aNode;
{
  nsString aResult;
  NSString * resultString = nil;

  nsresult        rv;
  nsIRDFResource  *resource;
  nsIRDFLiteral   *literal;
  nsIRDFDate      *dateLiteral;
  nsIRDFInt       *intLiteral;
  if (! aNode)
  {
    aResult.Truncate();
    rv = NS_OK;
  }
  else if (NS_SUCCEEDED(rv = aNode->QueryInterface(NS_GET_IID(nsIRDFResource), (void**) &resource)))
  {
    const char  *p = nsnull;
    if (NS_SUCCEEDED(rv = resource->GetValueConst( &p )) && (p))
    {
      aResult.AssignWithConversion(p);
    }
    NS_RELEASE(resource);
  }
  else if (NS_SUCCEEDED(rv = aNode->QueryInterface(NS_GET_IID(nsIRDFDate), (void**) &dateLiteral)))
  {
    PRInt64     theDate, million;
    if (NS_SUCCEEDED(rv = dateLiteral->GetValue( &theDate )))
    {
      LL_I2L(million, PR_USEC_PER_SEC);
      LL_DIV(theDate, theDate, million);          // convert from microseconds (PRTime) to seconds
      PRInt32     now32;
      LL_L2I(now32, theDate);
      double interval = (double)now32;
      NSDate * date = [NSDate dateWithTimeIntervalSince1970:interval];
      resultString = [date description];
    }
    NS_RELEASE(dateLiteral);
  }
  else if (NS_SUCCEEDED(rv = aNode->QueryInterface(NS_GET_IID(nsIRDFInt), (void**) &intLiteral)))
  {
    PRInt32     theInt;
    aResult.Truncate();
    if (NS_SUCCEEDED(rv = intLiteral->GetValue( &theInt )))
    {
      aResult.AppendInt(theInt, 10);
    }
    NS_RELEASE(intLiteral);
  }
  else if (NS_SUCCEEDED(rv = aNode->QueryInterface(NS_GET_IID(nsIRDFLiteral), (void**) &literal)))
  {
    const PRUnichar     *p = nsnull;
    if (NS_SUCCEEDED(rv = literal->GetValueConst( &p )) && (p))
    {
      aResult = p;
    }
    NS_RELEASE(literal);
  }
  else
  {
    NS_ERROR("not a resource or a literal");
    rv = NS_ERROR_UNEXPECTED;
    return @"Not a resource or a literal";
  }
  if( !resultString )
    resultString = [NSString stringWith_nsAString:aResult];
  return resultString;
}

@end
